## HEADER ####
## What: ***** ****** Wooley Apple aphid data - initial peek
## When: Last edited 2021-06-15
## Who: Last editor, EH


## CONTENTS ####
## 00 Setup
## 01 Graphs
## 02 Analysis


## 00 Setup ####

# Ed wd
setwd(r'(D:\Dropbox\WORK\__Harper Adams stuff\HARPER HARUG R Users Group\2021-06-15 tidy stuff, 2 examples)')

library(openxlsx) # reads in excel files
library(ape) # for Moran.I()

dat <- read.xlsx('waa-data-2021-06-15.xlsx')

# Fix vars
dat$block <- as.factor(dat$block)
dat$severity <- as.factor(dat$severity)
dat$ants <- as.factor(dat$ants)
dat$aphids <- as.factor(dat$aphids)

# make total aphids var
dat$waa.total <- rowSums(dat[, c('waa.root', 'waa.trunk', 'waa.branch')])

## 01 Graphs ####

### 01.01 Simplest base R x-y total waa ####
plot(
        x = dat$xcoord,
        y = dat$ycoord,
        cex = .1 + (dat$waa.total / 5),
        xlim = c(0, 75),
        main = 'Show me the (Wooley apple) aphids',
        ylab = 'Tree position y',
        xlab = 'Tree position x',
        pch = 9
)

legend(
        x = 40,
        y = 55,
        legend = c(paste('   ', min(dat$waa.total), "aphids"),
                   '',
                   paste('   ', max(dat$waa.total), "aphids")),
        pch = 9,
        pt.cex = c(.1 + min(dat$waa.total), 0,
                   .1 + max(dat$waa.total / 5)),
        bty = 'n'
)

### 01.02 Simplest base R x-y total waa ####
plot(
        x = dat$xcoord,
        y = dat$ycoord,
        cex = .1+dat$webs,
        xlim = c(0, 75),
        main = 'Show me the \"webs\"',
        ylab = 'Tree position y',
        xlab = 'Tree position x',
        pch = 9
)

legend(
        x = 40,
        y = 55,
        legend = c(paste('   ', min(dat$webs), "webs"),
                   '',
                   paste('   ', max(dat$webs), "webs")),
        pch = 9,
        pt.cex = c(.1 + min(dat$webs), 0,
                   .1 + max(dat$webs)),
        bty = 'n'
)

###

## 02 Analysis ####

### 02.01 Is there spatial correlation in aphid colony count? ####
# e.g. https://stats.idre.ucla.edu/other/mult-pkg/faq/general/faq-how-can-i-detectaddress-spatial-autocorrelation-in-my-data/
# (aka spatial autocorrelation)
# Moran's I

# Make distance matrix for trees
treedist <- as.matrix(dist(cbind(dat$ycoord, dat$xcoord)))
treedist.inv <- 1/treedist # inverse distance matrix
diag(treedist.inv) <- 0

# waa 
Moran.I(dat$waa.total, treedist.inv) # not different to random!

# webs
Moran.I(dat$webs, treedist.inv) # not different to random!

Moran.I(dat$webs, treedist.inv) # not different to random!

### 02.02 Are blocks different in aphid colony count? ####
boxplot(log(waa.total+1) ~ block, data = dat)
lm1 <- lm(log(waa.total+1) ~ block, data = dat)
anova(lm1)
summary(lm1)
